@@ -37,16 +37,15 @@ of smaller lists for display purposes)
 
 =cut
 
+use 5.005;
 use strict;
-use base 'Template::Plugin';
-use Template::Plugin;
-use Params::Util '_ARRAY',
-                 '_HASH',
-                 '_INSTANCE';
+use Template::Plugin ();
+use Params::Util     qw{ _ARRAY _HASH _INSTANCE };
 
-use vars qw{$VERSION};
+use vars qw{$VERSION @ISA};
 BEGIN {
-	$VERSION = '0.02';
+	$VERSION = '1.03';
+	@ISA     = 'Template::Plugin';
 }
 
 
@@ -140,14 +139,11 @@ For other issues, or commercial enhancement or support, contact the author.
 
 =head1 AUTHOR
 
-Adam Kennedy E<lt>cpan@ali.asE<gt>, L<http://ali.as/>
-
-Thank you to Phase N Australia (L<http://phase-n.com/>) for permitting the
-open sourcing and release of this distribution.
+Adam Kennedy E<lt>cpan@ali.asE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2004 - 2005 Adam Kennedy. All rights reserved.
+Copyright 2004 - 2008 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
